==> wire-runtime-jvm-4.1.0-javadoc.jar: wire-runtime/com.squareup.wire/-wire-field/-label/-o-m-i-t_-i-d-e-n-t-i-t-y/index.md <==
//[wire-runtime](../../../../../index.md)/[com.squareup.wire](../../../index.md)/[WireField](../../index.md)/[Label](../index.md)/[OMIT_IDENTITY](index.md)

# OMIT_IDENTITY

[common]\
[OMIT_IDENTITY](index.md)()

Special label to defines proto3 fields which should not be emitted if their value is equal to their type's respective identity value. E.g.: a field of type int32 will not get emitted if its value is 0.

## Properties

| Name | Summary |
|---|---|
| [isOneOf](../is-one-of.md) | [common]<br>@get:[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = "isOneOf")<br>val [isOneOf](../is-one-of.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isPacked](../is-packed.md) | [common]<br>@get:[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = "isPacked")<br>val [isPacked](../is-packed.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isRepeated](../is-repeated.md) | [common]<br>@get:[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = "isRepeated")<br>val [isRepeated](../is-repeated.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [name](../-r-e-q-u-i-r-e-d/index.md#-372974862%2FProperties%2F-1082500773) | [common]<br>val [name](../-r-e-q-u-i-r-e-d/index.md#-372974862%2FProperties%2F-1082500773): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](../-r-e-q-u-i-r-e-d/index.md#-739389684%2FProperties%2F-1082500773) | [common]<br>val [ordinal](../-r-e-q-u-i-r-e-d/index.md#-739389684%2FProperties%2F-1082500773): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |

==> wire-runtime-jvm-4.3.0-javadoc.jar: wire-runtime/com.squareup.wire/-wire-field/-label/-o-m-i-t_-i-d-e-n-t-i-t-y/index.md <==
//[wire-runtime](../../../../../index.md)/[com.squareup.wire](../../../index.md)/[WireField](../../index.md)/[Label](../index.md)/[OMIT_IDENTITY](index.md)

# OMIT_IDENTITY

[common]\
[OMIT_IDENTITY](index.md)()

Special label to define proto3 fields which should not be emitted if their value is equal to their type's respective identity value. E.g.: a field of type int32 will not get emitted if its value is 0.

## Properties

| Name | Summary |
|---|---|
| [isOneOf](../is-one-of.md) | [common]<br>@get:[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = "isOneOf")<br>val [isOneOf](../is-one-of.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isPacked](../is-packed.md) | [common]<br>@get:[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = "isPacked")<br>val [isPacked](../is-packed.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [isRepeated](../is-repeated.md) | [common]<br>@get:[JvmName](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.jvm/-jvm-name/index.html)(name = "isRepeated")<br>val [isRepeated](../is-repeated.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [name](../-r-e-q-u-i-r-e-d/index.md#-372974862%2FProperties%2F-1082500773) | [common]<br>val [name](../-r-e-q-u-i-r-e-d/index.md#-372974862%2FProperties%2F-1082500773): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [ordinal](../-r-e-q-u-i-r-e-d/index.md#-739389684%2FProperties%2F-1082500773) | [common]<br>val [ordinal](../-r-e-q-u-i-r-e-d/index.md#-739389684%2FProperties%2F-1082500773): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
